# aiida-optimize

Defines AiiDA workchains that simplify running optimization workflows.

Documentation: http://aiida-optimize.readthedocs.io

[![Build Status](https://travis-ci.org/greschd/aiida-optimize.svg?branch=develop)](https://travis-ci.org/greschd/aiida-optimize) [![Documentation Status](https://readthedocs.org/projects/aiida-optimize/badge/?version=latest)](https://aiida-optimize.readthedocs.io/en/latest/?badge=latest)
